@@ -86,11 +86,10 @@ class LVMTemplateForm(NetBoxModelForm):
     )
 
     class Meta:
-        model = MountedVolume
+        model = LogicalVolume
         fields = [
-            "mountpoint",
-            "fs_type",
-            "fs_options"
+            "lv_name",
+            "size",
         ]
 
     def save(self, *args, **kwargs):
@@ -104,48 +103,55 @@ class LVMTemplateForm(NetBoxModelForm):
         print(f"Filesystem Options: {self.cleaned_data['fs_options']}")
         print(f"Checkbox Partition: {self.cleaned_data['checkbox_partition']}")
 
-        new_partition_count = Partition.objects.filter(drive_id=self.cleaned_data['drive'].id).count() + 1
         device_name_prefix = Drive.objects.get(pk=self.cleaned_data['drive'].id).device_name()
-        print(f"Partition Count: {new_partition_count}")
         print(f"Device Name: {device_name_prefix}")
-        device_name = device_name_prefix + str(new_partition_count)
-        # mounted_volume = MountedVolume.objects.create(mount_point=self.cleaned_data['mountpoint'],
-        #                                               fs_type=self.cleaned_data['fs_type'],
-        #                                               options=self.cleaned_data['fs_options'])
-        # mounted_volume.save()
-        mounted_volume = super().save(*args, **kwargs)
-        print(f"Mounted Volume ID: {mounted_volume.id}")
 
-        linux_device = LinuxDevice.objects.create(device=device_name, type='efi')
-        linux_device.save()
-        print(f"Linux Device ID: {linux_device.id}")
-
-        partition = Partition.objects.create(drive=self.cleaned_data['drive'], device=linux_device,
-                                             size=self.cleaned_data['size'], type='Linux LVM')
-        partition.save()
-        print(f"Partition ID: {partition.id}")
+        linux_parent_device = LinuxDevice.objects.get(device=device_name_prefix)
+        pv_linux_device = None
+        if self.cleaned_data['checkbox_partition']:
+            device_name = device_name_prefix + str(1)
+            linuxdevice_type_pk = ContentType.objects.get(app_label='netbox_storage', model='linuxdevice').pk
+            pv_linux_device = LinuxDevice.objects.create(device=device_name,
+                                                         type='Partition',
+                                                         size=linux_parent_device.size,
+                                                         object_id=linux_parent_device.pk,
+                                                         content_type_id=linuxdevice_type_pk)
+            pv_linux_device.save()
+        else:
+            pv_linux_device = linux_parent_device
 
         volume_group = VolumeGroup.objects.create(vg_name=self.cleaned_data['vg_name'])
         volume_group.save()
-        print(f"Volume Group ID: {volume_group.id}")
+        #print(f"Volume Group ID: {volume_group.id}")
 
-        pv = PhysicalVolume.objects.create(device=linux_device, vg=volume_group)
-        pv.save()
-        print(f"Physical Volume ID: {pv.id}")
+        #pv = PhysicalVolume.objects.create(device=pv_linux_device, vg=volume_group)
+        #pv.save()
+        #print(f"Physical Volume ID: {pv.id}")
 
         # Add linux_device for lvm
+        pv_type_pk = ContentType.objects.get(app_label='netbox_storage', model='volumegroup').pk
         linux_device_mapper = LinuxDevice.objects.create(device='/dev/mapper/vg_system-lv_home',
-                                                         type='efi')
+                                                         type='LVM',
+                                                         size=pv_linux_device.size,
+                                                         object_id=volume_group.pk,
+                                                         content_type_id=pv_type_pk)
         linux_device_mapper.save()
-        print(f"Linux Device ID: {linux_device_mapper.id}")
+        #print(f"Linux Device ID: {linux_device_mapper.id}")
 
-        lv = LogicalVolume.objects.create(vg=volume_group, lv_name=self.cleaned_data['lv_name'],
-                                          size=self.cleaned_data['size'], device=linux_device_mapper)
-        lv.save()
-        print(f"{lv}")
-        return mounted_volume
+        self.instance.vg = volume_group
+        self.instance.device = linux_device_mapper
+        #lv = LogicalVolume.objects.create(vg=volume_group, lv_name=self.cleaned_data['lv_name'],
+        #                                  size=self.cleaned_data['size'], device=linux_device_mapper)
+        #lv.save()
+        #print(f"{lv}")
+        lv = super().save(*args, **kwargs)
+
+        return lv
 
 
+#
+# Add Drive template form
+#
 class DriveTemplateForm(NetBoxModelForm):
     size = FloatField(
         label="Size (GB)",
@@ -190,10 +196,7 @@ class DriveTemplateForm(NetBoxModelForm):
         drive = Drive.objects.create(cluster=self.cleaned_data['cluster'], size=self.cleaned_data['size'])
         self.instance.drive = drive
         template_configuration = super().save(*args, **kwargs)
-
-        print(f"{self.cleaned_data['size']}")
         drive_type_pk = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
-
         linux_device = LinuxDevice.objects.create(device=drive.device_name(),
                                                   type='disk',
                                                   size=self.cleaned_data['size'],
