@@ -18,6 +18,10 @@ class LinuxDeviceTable(NetBoxTable):
         linkify=True,
         verbose_name="Type"
     )
+    object = tables.Column(
+        linkify=True,
+        verbose_name="Type"
+    )
 
     class Meta(NetBoxTable.Meta):
         model = LinuxDevice
@@ -25,9 +29,11 @@ class LinuxDeviceTable(NetBoxTable):
             "pk",
             "device",
             "type",
+            "object"
         )
         default_columns = (
             "pk",
             "device",
             "type",
+            "object"
         )
